@@ -28,6 +28,10 @@ class Update:
 			self.cloneSvn(repo)
 
 	def pull(self, repo):
+		if not util.checkRemote(repo):
+			error = "{0} has a different remote on disk than in config".format(repo['local'])
+			terminal.error("\n" + error)
+			dolly.Dolly.warnings.append(error)
 		if util.isGitRepo(repo):
 			self.pullGit(repo)
 		else:
@@ -37,7 +41,7 @@ class Update:
 		result = util.executeCommand('git clone {0} {1}'.format(repo['remote'], repo['local']))
 
 	def cloneSvn(self, repo):
-		result = util.executeCommand('svn checkout {0} {1}'.format(repo['remote'], repo['local']))
+		result = util.executeCommand('svn checkout --config-option servers:global:store-plaintext-passwords=yes {0} {1}'.format(repo['remote'], repo['local']))
 
 	def pullGit(self, repo):
 		result = util.executeCommand('git pull --ff-only', cwd=repo['local'])
